#
# spec file for package python-pykickstart
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global mod_name pykickstart
%bcond_without libalternatives
# Python 2 isn't supported...
Name:           python-%{mod_name}
Version:        3.54
Release:        2.1
Summary:        Python module for parsing and writing kickstart files
License:        GPL-2.0-only AND MIT
Group:          Development/Libraries/Python
URL:            https://fedoraproject.org/wiki/pykickstart
Source0:        https://github.com/pykickstart/pykickstart/releases/download/r%{version}/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
Pykickstart is a Python library consisting of a data representation
of kickstart files, a parser to read files into that representation,
and a writer to generate kickstart files.

%prep
%autosetup -n %{mod_name}-%{version} -p1

%build
# Build all the translations and such
%make_build PYTHON=python3

%pyproject_wheel

%install
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/ksflatten
%python_clone -a %{buildroot}%{_mandir}/man1/ksflatten.1
%python_clone -a %{buildroot}%{_bindir}/ksshell
%python_clone -a %{buildroot}%{_mandir}/man1/ksshell.1
%python_clone -a %{buildroot}%{_bindir}/ksvalidator
%python_clone -a %{buildroot}%{_mandir}/man1/ksvalidator.1
%python_clone -a %{buildroot}%{_bindir}/ksverdiff
%python_clone -a %{buildroot}%{_mandir}/man1/ksverdiff.1

%check
%python_expand PYTHONPATH=.. $python -m unittest discover -v

%pre
%python_libalternatives_reset_alternative ksflatten
%python_libalternatives_reset_alternative ksshell
%python_libalternatives_reset_alternative ksvalidator
%python_libalternatives_reset_alternative ksverdiff

%files %{python_files}
%license COPYING
%doc README.rst
%doc data/kickstart.vim
%doc docs/2to3
%doc docs/programmers-guide
%doc docs/kickstart-docs.txt
%{python_sitelib}/%{mod_name}/
%{python_sitelib}/%{mod_name}-*
%python_alternative %{_bindir}/ksflatten
%python_alternative %{_mandir}/man1/ksflatten.1%{?ext_man}
%python_alternative %{_bindir}/ksshell
%python_alternative %{_mandir}/man1/ksshell.1%{?ext_man}
%python_alternative %{_bindir}/ksvalidator
%python_alternative %{_mandir}/man1/ksvalidator.1%{?ext_man}
%python_alternative %{_bindir}/ksverdiff
%python_alternative %{_mandir}/man1/ksverdiff.1%{?ext_man}

%changelog
* Tue Jun 10 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build and libalternatives
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 3.54:
  * Add a DEFAULT_VERSION variable to version.py (bcl)
  * Deprecate network team options on RHEL 10 (rvykydal)
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 3.53:
  * Do some workflow maintenance
  * Add RHEL 10 handler to master branch
  * Add Fedora 41 support
  * Update kickstart-docs.rst
  * Add missing rhsm and syspurpose commands
- update to 3.47:
  * displaymode: Update description to describe behavior
  * network: Move new options to Fedora 39
- update to 3.46:
  * Add conflict test between ostree sources
  * Fix missing seen check for output generation
  * Add new ostreecontainer command
  * Check the conflicting commands automatically (vponcova)
  * Fix tests for conflicting commands (vponcova)
  * Add conflicting commands support (bcl)
  * Fix handling of package section arguments in older versions
- update to 3.45:
  * Don't allow to use --sdboot and --extlinux together
  * tests: add bootloader sdboot option (jeremy.linton)
  * bootloader: Add systemd-boot support with --sdboot
  * Add %%changelog section to pykickstart.spec.in (jkonecny)
  * Do not request sign for rc-release Makefile target (jkonecny)
  * Do not require SPECFILE for rc-release (jkonecny)
  * Add missing docs copy to scratch Makefile (jkonecny)
  * Add support for Fedora 39 (vslavik)
* Tue Mar  7 2023 pgajdos@suse.com
- python-six is not required
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.34
  * Remove the auth and authconfig commands (pbrezina)
  The parse method is expected to return a value (vponcova)
  tests: unittest isn't used in handle_unicode anymore (bcl)
  Add RHEL 9 handler (mkolman)
  Resolves: rhbz#1966730
  Add RHEL 9 version for commands that had a RHEL version in the past (mkolman)
  Add RHEL 9 version for BTRFS related commands (mkolman)
* Sun Jan 31 2021 Neal Gompa <ngompa13@gmail.com>
- Adapt for new singlespec style
* Sun Dec 20 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 3.30
  + Add new timesource command
  + Deprecate the --ntpservers and --nontp options of the timezone command
  + Remove --biospart argument from harddrive command, it was never implemented or used.
  + Add Fedora 34 handler
* Wed May 20 2020 Neal Gompa <ngompa13@gmail.com>
- Drop unused nose and coverage test dependencies
- Drop unused Sphinx dependency for docs
* Mon Apr 20 2020 Neal Gompa <ngompa13@gmail.com>
- Sync disable for running tests in package builds from Fedora
* Mon Apr 20 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 3.25
  + Add Fedora 33 support
  + Add Fedora 32 support
  + Drop Python 2 compatibility
* Sat Mar  2 2019 Neal Gompa <ngompa13@gmail.com>
- Initial packaging for openSUSE
